@@ -5,12 +5,20 @@
 # in this file that begin with Mail.
 #
 # Brent Welch (c) 1997 Sun Microsystems
+# Brent Welch (c) 1998-2000 Ajuba Solutions
 # See the file "license.terms" for information on usage and redistribution
 # of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 #
-# SCCS: @(#) mail.tcl 1.1 97/06/26 15:11:35
+# RCS: @(#) $Id: mail.tcl,v 1.11 2000/08/02 07:06:53 welch Exp $
 
-package provide mail 1.0
+package provide httpd::mail 1.0
+
+foreach f {/usr/lib/sendmail /usr/sbin/sendmail} {
+    if {[file exists $f]} {
+	set Mail(program) $f
+	break
+    }
+}
 
 proc Mail_Url {dir} {
     Direct_Url $dir Mail
@@ -53,7 +61,7 @@ proc Mail/forminfo {sendto subject href label args} {
 	set blob [list $value]
 	if {[regsub -all \\\\ $blob {} _] > 0} {
 	    append message "[list Data64 $name] \\\n"
-	    append message [list [Base64_Encode $value]]\n
+	    append message [list [base64::encode $value]]\n
 	} else {
 	    append message [list Data $name $value]\n
 	}
@@ -96,7 +104,7 @@ proc Mail/formdata {email subject args} {
 }
 
 proc MailInner {sendto subject from type body} {
-    global tcl_platform
+    global tcl_platform Mail
     set headers  \
 "To: $sendto
 Subject: $subject
@@ -108,21 +116,17 @@ Content-Type: $type"
 
     set message "$headers\n\n$body"
 
-    switch $tcl_platform(platform) {
-	unix {
-	    if {[catch {
-		exec /usr/lib/sendmail $sendto << $message
-	    } err]} {
-		Stderr "ERROR: $err"
-		Stderr $message
-	    } else {
-		return "<font size=+1><b>Thank You!</font></b><p>Mailed report to <b>$sendto</b>"
-	    }
-	}
-	default	{
-	    Stderr $message
+    if {[info exists Mail(program)]} {
+	if {[catch {
+	    exec $Mail(program) $sendto << $message
+	} err]} {
+	    Log "" MailError $err
+	} else {
+	    return "<font size=+1><b>Thank You!</font></b><p>Mailed report to <b>$sendto</b>"
 	}
+    } else {
+	Log "" NoMailProgram
+	return "Unable to send mail"
     }
-    return "Unable to send mail"
 }
 
